@@ -1,5 +1,5 @@
 # ************************************************************************* 
-# Copyright (c) 2014, SUSE LLC
+# Copyright (c) 2014-2015, SUSE LLC
 # 
 # All rights reserved.
 # 
@@ -152,8 +152,8 @@ sub initialize_unit {
     # add Web::Machine object to payload
     $status->payload( Web::Machine->new( resource => 'App::Dochazka::REST::Dispatch', )->to_app );
 
-    # initialize App::Dochazka package variables $t, $today, etc.
-    App::Dochazka::init_timepiece();
+    # initialize App::Dochazka::Common package variables $t, $today, etc.
+    App::Dochazka::Common::init_timepiece();
 
     return $status;
 }
